==> fw4spl_11.0.4.orig.tar.gz: fw4spl-11.0.4/SrcLib/core/fwRuntime/src/EConfigurationElement.cpp <==
/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2017.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#include "fwRuntime/EConfigurationElement.hpp"

#include "fwRuntime/Bundle.hpp"

namespace fwRuntime
{

EConfigurationElement::EConfigurationElement(const std::string& name) :
    ::fwRuntime::ConfigurationElement( std::shared_ptr< ::fwRuntime::Bundle >(), name )
{
}

EConfigurationElement::~EConfigurationElement()
{
}

//------------------------------------------------------------------------------

EConfigurationElement::sptr EConfigurationElement::addConfigurationElement( const std::string& name )
{
    EConfigurationElement::sptr cfg = EConfigurationElement::New(name);
    this->::fwRuntime::ConfigurationElement::addConfigurationElement( cfg );
    return cfg;
}

//------------------------------------------------------------------------------

void EConfigurationElement::addConfigurationElement( EConfigurationElement::sptr element )
{
    this->::fwRuntime::ConfigurationElement::addConfigurationElement( element );
}

//------------------------------------------------------------------------------

void EConfigurationElement::setAttributeValue(const std::string& name, const std::string& value) throw()
{
    this->::fwRuntime::ConfigurationElement::setAttributeValue( name, value );
}

//------------------------------------------------------------------------------

void EConfigurationElement::setValue(const std::string& value) throw()
{
    this->::fwRuntime::ConfigurationElement::setValue(value);
}

}

==> fw4spl_17.2.0.orig.tar.gz: fw4spl-17.2.0/SrcLib/core/fwRuntime/src/EConfigurationElement.cpp <==
/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2017.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#include "fwRuntime/EConfigurationElement.hpp"

#include "fwRuntime/Bundle.hpp"

namespace fwRuntime
{

EConfigurationElement::EConfigurationElement(const std::string& name) :
    ::fwRuntime::ConfigurationElement( std::shared_ptr< ::fwRuntime::Bundle >(), name )
{
}

EConfigurationElement::~EConfigurationElement()
{
}

//------------------------------------------------------------------------------

EConfigurationElement::sptr EConfigurationElement::addConfigurationElement( const std::string& name )
{
    EConfigurationElement::sptr cfg = EConfigurationElement::New(name);
    this->::fwRuntime::ConfigurationElement::addConfigurationElement( cfg );
    return cfg;
}

//------------------------------------------------------------------------------

void EConfigurationElement::addConfigurationElement( EConfigurationElement::sptr element )
{
    this->::fwRuntime::ConfigurationElement::addConfigurationElement( element );
}

//------------------------------------------------------------------------------

void EConfigurationElement::setAttributeValue(const std::string& name, const std::string& value) noexcept
{
    this->::fwRuntime::ConfigurationElement::setAttributeValue( name, value );
}

//------------------------------------------------------------------------------

void EConfigurationElement::setValue(const std::string& value) noexcept
{
    this->::fwRuntime::ConfigurationElement::setValue(value);
}

}
